Changelog
=========

| *Version 1.0.0*: Adding a module with application functions for the calculation of the IBP index as well as the graphical visualization.
| *Version 1.0.1*: Create Sphinx documentation.
| *Version 1.0.2*: Rebuild package structure.
| *Version 1.0.3*: Integration into Read the Docs (https://ibp-model.readthedocs.io)
| *Version 1.0.4*: Move from https://test.pypi.org to https://pypi.org
| *Version 1.1.0*: Update of the coefficient file (SW_OPER_IBP_CLI_2__00000000T000000_99999999T999999_0002.cdf)
| *Version 1.1.1*: Correction at Sphinx setting
| *Version 1.1.2*: Change package init settings
| *Version 1.2.0*: Adjustments to the plot functions
| *Version 1.2.1*: Limitation of Solar Radio Flux and output of a warning message; Partitioning requirements.txt
| *Version 1.2.2*: add reference (https://doi.org/10.1029/2023SW003809)
| *Version 1.3.0*: Update of the coefficient file (SW_OPER_IBP_CLI_2__00000000T000000_99999999T999999_0003.cdf), run with numpy 2.0 and cdflib 1.3
| *Version 1.4.0*: Update of the coefficient file (SW_OPER_IBP_CLI_2__00000000T000000_99999999T999999_0004.cdf)
| *Version 1.4.1*: Bug fix documentation
| *Version 1.4.2*: Bug fix documentation
